import {
	navigateTo,
	redirectTo,
	loading,
	message,
	confirm,
	alert
} from '../utils/fun.js';

const app = getApp();

export default {
	data() {
		return {
			xhrPool: new Set(),
			bottomSafePadding: app.globalData.bottomSafePadding,
			options: {},
			auth: false, // 登录验证
			paying: false, // 支付按钮状态
		};
	},
	onLoad(options) {
		this.options = options;

	},
	onShow() {
		this.loadData();
	},
	onHide() {
		if (this.xhrPool && this.xhrPool.size) {
			this.xhrPool.forEach((requestTask) => {
				requestTask.abort();
			})
		}
	},
	methods: {
		authTo(url) { //登录校验

		},
		authToNs(url) { //登录校验不保留当前页面

		},
		loadData() {},
		startPay() {
			loading.show();
			this.paying = true;
		},
		stopPay() {
			loading.hide();
			this.paying = false;
		},
		/**
		 * @param {Object} url 接口请求地址
		 * @param {Object} method 接口请求方式
		 * @param {Object} data 接口请求参数
		 */
		$http(url, method, data = {}, showLoading = false) {
			return new Promise((resolve, reject) => {
				this[method.toLowerCase()]({
					url: url,
					data: data,
					showLoading: showLoading,
					success: (res) => {
						resolve(res)
					},
					fail: (e) => {
						reject(e)
					}
				});
			})
		},
		login() {
			// navigateTo('user/login');
			// let redirect = this.$scope.$page.fullPath.replace('/pages', '');
			// console.log(redirect)
			// navigateTo('user/login?redirect=' + encodeURIComponent(redirect));
		},
		logout() {
			uni.removeStorageSync('token');
		},
		put(options) {
			options = Object.assign({
				showLoading: true
			}, options, {
				method: 'PUT'
			})
			this.req(options);
		},
		post(options) {
			options = Object.assign({
				showLoading: true
			}, options, {
				method: 'POST'
			})
			this.req(options);
		},
		get(options) {
			options = Object.assign({
				showLoading: false
			}, options, {
				method: 'GET'
			})
			this.req(options);
		},
		req(options) {
			let {
				showLoading,
				url,
				data,
				auth
			} = options;

			const success = options?.success;
			const fail = options?.fail;
			const header = options?.header ?? {};

			showLoading && loading.show();

			let requestTask;

			let uniChannel = 'wechat';

			// #ifdef MP-KUAISHOU
			uniChannel = 'kuaishou';
			// #endif

			// #ifdef MP-TOUTIAO
			uniChannel = 'douyin';
			// #endif

			Object.assign(header, {
				token: uni.getStorageSync('token'),
				pkgName: app.globalData.pkgName,
				version: app.globalData.versionName,
				proChannel: uniChannel
			})

			options = Object.assign(options, {
				url: `${app.globalData.baseUrl}${url}`,
				header,
				data,
				success: (res) => {
					showLoading && loading.hide();
					switch (res.data.status) {
						case 200:
							if (success) {
								success(res.data);
							}
							break;
						default:
							if (fail) {
								fail(res.data.message);
							}
							message.notify(res.data.message);
							break;
					}
				},
				fail: (e) => {
					message.notify('服务器开小差了');
					// alert({
					//   content: JSON.stringify(e)
					// });
					if (fail) {
						fail(e);
					}
				},
				complete: () => {
					if (this.xhrPool) {
						this.xhrPool.delete(requestTask)
					}
				}
			})

			requestTask = uni.request(options);
			if (this.xhrPool) {
				this.xhrPool.add(requestTask)
			}
		}
	}
};